@@ -4,19 +4,19 @@
  *  This code demonstrates two methods of monitoring both an lo_server
  *  and other I/O from a single thread.
  *
- *  Copyright (C) 2004 Steve Harris, Uwe Koloska
+ *  Copyright (C) 2014 Steve Harris et al. (see AUTHORS)
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU Lesser General Public License as
+ *  published by the Free Software Foundation; either version 2.1 of the
+ *  License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  $Id: nonblocking_server_example.c 63 2005-12-21 15:58:55Z nhumfrey $
+ *  $Id$
  */
 
 #include <stdio.h>
@@ -32,14 +32,14 @@ int done = 0;
 
 void error(int num, const char *m, const char *path);
 
-int generic_handler(const char *path, const char *types, lo_arg **argv,
-		    int argc, void *data, void *user_data);
+int generic_handler(const char *path, const char *types, lo_arg ** argv,
+                    int argc, void *data, void *user_data);
 
-int foo_handler(const char *path, const char *types, lo_arg **argv, int argc,
-		 void *data, void *user_data);
+int foo_handler(const char *path, const char *types, lo_arg ** argv,
+                int argc, void *data, void *user_data);
 
-int quit_handler(const char *path, const char *types, lo_arg **argv, int argc,
-		 void *data, void *user_data);
+int quit_handler(const char *path, const char *types, lo_arg ** argv,
+                 int argc, void *data, void *user_data);
 
 void read_stdin(void);
 
@@ -47,7 +47,9 @@ int main()
 {
     int lo_fd;
     fd_set rfds;
+#ifndef WIN32
     struct timeval tv;
+#endif
     int retval;
 
     /* start a new server on port 7770 */
@@ -67,7 +69,7 @@ int main()
     lo_fd = lo_server_get_socket_fd(s);
 
     if (lo_fd > 0) {
-        
+
         /* select() on lo_server fd is supported, so we'll use select()
          * to watch both stdin and the lo_server fd. */
 
@@ -75,11 +77,11 @@ int main()
 
             FD_ZERO(&rfds);
 #ifndef WIN32
-            FD_SET(0, &rfds);  /* stdin */
+            FD_SET(0, &rfds);   /* stdin */
 #endif
             FD_SET(lo_fd, &rfds);
 
-            retval = select(lo_fd + 1, &rfds, NULL, NULL, NULL); /* no timeout */
+            retval = select(lo_fd + 1, &rfds, NULL, NULL, NULL);        /* no timeout */
 
             if (retval == -1) {
 
@@ -107,7 +109,8 @@ int main()
         /* lo_server protocol does not support select(), so we'll watch
          * stdin while polling the lo_server. */
 #ifdef WIN32
-        printf("non-blocking input from stdin not supported under Windows\n");
+        printf
+            ("non-blocking input from stdin not supported under Windows\n");
         exit(1);
 #else
         do {
@@ -135,7 +138,7 @@ int main()
         } while (!done);
 #endif
     }
-    
+
     return 0;
 }
 
@@ -146,16 +149,16 @@ void error(int num, const char *msg, const char *path)
 
 /* catch any incoming messages and display them. returning 1 means that the
  * message has not been fully handled and the server should try other methods */
-int generic_handler(const char *path, const char *types, lo_arg **argv,
-		    int argc, void *data, void *user_data)
+int generic_handler(const char *path, const char *types, lo_arg ** argv,
+                    int argc, void *data, void *user_data)
 {
     int i;
 
     printf("path: <%s>\n", path);
-    for (i=0; i<argc; i++) {
-	printf("arg %d '%c' ", i, types[i]);
-	lo_arg_pp(types[i], argv[i]);
-	printf("\n");
+    for (i = 0; i < argc; i++) {
+        printf("arg %d '%c' ", i, types[i]);
+        lo_arg_pp((lo_type)types[i], argv[i]);
+        printf("\n");
     }
     printf("\n");
     fflush(stdout);
@@ -163,8 +166,8 @@ int generic_handler(const char *path, const char *types, lo_arg **argv,
     return 1;
 }
 
-int foo_handler(const char *path, const char *types, lo_arg **argv, int argc,
-		 void *data, void *user_data)
+int foo_handler(const char *path, const char *types, lo_arg ** argv,
+                int argc, void *data, void *user_data)
 {
     /* example showing pulling the argument values out of the argv array */
     printf("%s <- f:%f, i:%d\n\n", path, argv[0]->f, argv[1]->i);
@@ -173,8 +176,8 @@ int foo_handler(const char *path, const char *types, lo_arg **argv, int argc,
     return 0;
 }
 
-int quit_handler(const char *path, const char *types, lo_arg **argv, int argc,
-		 void *data, void *user_data)
+int quit_handler(const char *path, const char *types, lo_arg ** argv,
+                 int argc, void *data, void *user_data)
 {
     done = 1;
     printf("quiting\n\n");
