@@ -1,17 +1,17 @@
 /*
- *  Copyright (C) 2004 Steve Harris
+ *  Copyright (C) 2014 Steve Harris et al. (see AUTHORS)
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU Lesser General Public License as
+ *  published by the Free Software Foundation; either version 2.1 of the
+ *  License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  $Id: blob.c,v 1.1.1.1 2004/08/07 22:21:02 theno23 Exp $
+ *  $Id$
  */
 
 #include <stdlib.h>
@@ -20,12 +20,12 @@
 #include "lo_types_internal.h"
 #include "lo/lo.h"
 
-lo_blob lo_blob_new(int32_t size, void *data)
+lo_blob lo_blob_new(int32_t size, const void *data)
 {
     lo_blob b;
 
     if (size < 1) {
-	return NULL;
+        return NULL;
     }
 
     b = malloc(sizeof(size) + size);
@@ -33,7 +33,7 @@ lo_blob lo_blob_new(int32_t size, void *data)
     b->size = size;
 
     if (data) {
-	memcpy(&(b->data), data, size);
+        memcpy((char *) b + sizeof(uint32_t), data, size);
     }
 
     return b;
@@ -51,14 +51,14 @@ uint32_t lo_blob_datasize(lo_blob b)
 
 void *lo_blob_dataptr(lo_blob b)
 {
-    return &(b->data);
+    return (char *) b + sizeof(uint32_t);
 }
 
 uint32_t lo_blobsize(lo_blob b)
 {
-    const int len = sizeof(uint32_t) + b->size;
+    const uint32_t len = sizeof(uint32_t) + b->size;
 
-    return 4 * (len / 4 + 1);
+    return 4 * ((len + 3) / 4);
 }
 
 /* vi:set ts=8 sts=4 sw=4: */
